from behave import *
from volworld_aws_api_common.test.behave.row_utils import (
    update_order_type_of_list, w__tags_of_all_rows_are_showing, w__tags_of_all_rows_are_not_showing)

from volworld_aws_api_common.api.AA import AA
from volworld_aws_api_common.test.behave.selenium_utils import w__get_element_by_shown_dom_id


@when('{mentor} update [order] type of list page to {sort_dir}')
def when__update_order_type_of_list_page(c, mentor: str, sort_dir: str):
    update_order_type_of_list(c, sort_dir)


@then('tags of all rows are showing')
def then__tags_of_all_rows_are_showing(c):
    w__tags_of_all_rows_are_showing(c)


@then('tags of all rows are not showing')
def then__tags_of_all_rows_are_not_showing(c):
    w__tags_of_all_rows_are_not_showing(c)


@then('there is no row in list page')
def then__there_is_no_row_in_list_page(c):
    elm = w__get_element_by_shown_dom_id(c, [AA.Empty, AA.InfoRow, AA.List])
    assert elm is not None


from typing import Final
from volworld_common.api.CA import CA


# ====== A: Attribute ======
class AA(CA):

    Bar: Final[str] = "bar"
    BottomAppBar: Final[str] = "btmab"

    CheckBox: Final[str] = "chkbx"
    Circle: Final[str] = "cce"

    Edit: Final[str] = "edt"
    Editor: Final[str] = "edr"
    Existing: Final[str] = "extg"

    Filled: Final[str] = "fld"

    LearnerRefWf: Final[str] = "lwf"
    LearnerSaLogId: Final[str] = "lrsalid"
    Left: Final[str] = "lft"
    Link: Final[str] = "lnk"
    Load: Final[str] = "lod"
    Logout: Final[str] = "lgo"

    Memorized: Final[str] = "mmd"
    MoreActions: Final[str] = "mact"

    Switch: Final[str] = "sth"

    Waiting: Final[str] = "wtg"

AAList = [AA, CA]
